@@ -4,6 +4,8 @@
 
 #include "opencv2/highgui/highgui.hpp"
 #include "opencv2/imgproc/imgproc.hpp"
+#include "detection/detector_types.h"
+#include "prewarp.h"
 #include "alpr_impl.h"
 #include "benchmark_utils.h"
 
