@@ -45,6 +45,8 @@ namespace alpr
       return;
     }
 
+    prewarp = new PreWarp(config);
+    
     loadRecognizers();
 
     setNumThreads(0);
@@ -53,8 +55,6 @@ namespace alpr
     this->topN = DEFAULT_TOPN;
     setDefaultRegion("");
     
-    prewarp = new PreWarp(config);
-    
     timespec endTime;
     getTimeMonotonic(&endTime);
     if (config->debugTiming)
@@ -125,22 +125,33 @@ namespace alpr
 
     // Iterate through each country provided (typically just one)
     // and aggregate the results if necessary
-    ResultAggregator aggregator;
+    ResultAggregator country_aggregator(MERGE_PICK_BEST, topN, config);
     for (unsigned int i = 0; i < config->loaded_countries.size(); i++)
     {
       if (config->debugGeneral)
         cout << "Analyzing: " << config->loaded_countries[i] << endl;
 
       config->setCountry(config->loaded_countries[i]);
-      AlprFullDetails sub_results = analyzeSingleCountry(img, grayImg, warpedRegionsOfInterest);
-
+      
+      // Reapply analysis for each multiple analysis value set in the config,
+      // make a minor imperceptible tweak to the input image each time
+      ResultAggregator iter_aggregator(MERGE_COMBINE, topN, config);
+      for (unsigned int iteration = 0; iteration < config->analysis_count; iteration++)
+      {
+        Mat iteration_image = iter_aggregator.applyImperceptibleChange(grayImg, iteration);
+        //drawAndWait(iteration_image);
+        AlprFullDetails iter_results = analyzeSingleCountry(img, iteration_image, warpedRegionsOfInterest);
+        iter_aggregator.addResults(iter_results);
+      }
+      
+      AlprFullDetails sub_results = iter_aggregator.getAggregateResults();
       sub_results.results.epoch_time = start_time;
       sub_results.results.img_width = img.cols;
       sub_results.results.img_height = img.rows;
       
-      aggregator.addResults(sub_results);
+      country_aggregator.addResults(sub_results);
     }
-    response = aggregator.getAggregateResults();
+    response = country_aggregator.getAggregateResults();
 
     timespec endTime;
     getTimeMonotonic(&endTime);
@@ -669,6 +680,25 @@ namespace alpr
     else
       prewarp->initialize(prewarp_config);
   }
+  
+  void AlprImpl::setMask(unsigned char* pixelData, int bytesPerPixel, int imgWidth, int imgHeight) {
+
+    try
+    {
+      int arraySize = imgWidth * imgHeight * bytesPerPixel;
+      cv::Mat imgData = cv::Mat(arraySize, 1, CV_8U, pixelData);
+      cv::Mat mask = imgData.reshape(bytesPerPixel, imgHeight);
+
+      typedef std::map<std::string, AlprRecognizers>::iterator it_type;
+      for (it_type iterator = recognizers.begin(); iterator != recognizers.end(); iterator++)
+        iterator->second.plateDetector->setMask(mask);
+    }
+    catch (cv::Exception& e)
+    {
+      std::cerr << "Caught (and ignoring) error in setMask: " << e.msg << std::endl;
+    }
+  }
+
 
 
   void AlprImpl::setDetectRegion(bool detectRegion)
@@ -705,8 +735,8 @@ namespace alpr
       {
         // Country training data has not already been loaded.  Load it.
         AlprRecognizers recognizer;
-        recognizer.plateDetector = createDetector(config);
-        recognizer.ocr = new OCR(config);
+        recognizer.plateDetector = createDetector(config, prewarp);
+        recognizer.ocr = createOcr(config);
 
         #ifndef SKIP_STATE_DETECTION
         recognizer.stateDetector = new StateDetector(this->config->country, this->config->config_file_path, this->config->runtimeBaseDir);
